[java-shib-shared] branch main updated: Fix javadoc issues, rename an oddly named support method.

Codeberg noreply at shibboleth.net
Mon Jul 13 12:48:22 UTC 2026


This is an automated email from the git hooks/post-receive script.

codeberg pushed a commit to branch main
in repository java-shib-shared.

View the commit online:
https://codeberg.org/Shibboleth/java-shib-shared/commit/b935e8ed1b7305ddff7345c3636c20d73911b037

The following commit(s) were added to refs/heads/main by this push:
     new b935e8ed Fix javadoc issues, rename an oddly named support method.
b935e8ed is described below

commit b935e8ed1b7305ddff7345c3636c20d73911b037
Author: Scott Cantor <scott at restingparrotsoftware.com>
AuthorDate: Mon Jul 13 08:48:09 2026 -0400

    Fix javadoc issues, rename an oddly named support method.
---
 .../spring/factory/AbstractComponentAwareFactoryBean.java |  7 ++++---
 .../shared/component/AbstractInitializableComponent.java  | 14 +++++++++++---
 .../shibboleth/shared/primitive/AnnotationsSupport.java   | 15 +++++++++++----
 .../shared/primitive/AnnotationsSupportTest.java          |  9 +++++----
 4 files changed, 31 insertions(+), 14 deletions(-)

diff --git a/shib-spring/src/main/java/net/shibboleth/shared/spring/factory/AbstractComponentAwareFactoryBean.java b/shib-spring/src/main/java/net/shibboleth/shared/spring/factory/AbstractComponentAwareFactoryBean.java
index a1643e55..d009e315 100644
--- a/shib-spring/src/main/java/net/shibboleth/shared/spring/factory/AbstractComponentAwareFactoryBean.java
+++ b/shib-spring/src/main/java/net/shibboleth/shared/spring/factory/AbstractComponentAwareFactoryBean.java
@@ -59,7 +59,7 @@ public abstract class AbstractComponentAwareFactoryBean<T> extends AbstractFacto
      * 
      * <p>Defaults to true.</p>
      * 
-     * @param flag
+     * @param flag flag to set
      * 
      * @since 9.1.0
      */
@@ -96,8 +96,9 @@ public abstract class AbstractComponentAwareFactoryBean<T> extends AbstractFacto
     /**
      * Call the parent class to create the instance.
      * 
-     * @return the bean.
-     * @throws Exception if needed.
+     * @return the bean
+     * 
+     * @throws Exception if needed
      */
     @Nullable protected abstract T doCreateInstance() throws Exception;
 
diff --git a/shib-support/src/main/java/net/shibboleth/shared/component/AbstractInitializableComponent.java b/shib-support/src/main/java/net/shibboleth/shared/component/AbstractInitializableComponent.java
index 23ec8986..3332a69a 100644
--- a/shib-support/src/main/java/net/shibboleth/shared/component/AbstractInitializableComponent.java
+++ b/shib-support/src/main/java/net/shibboleth/shared/component/AbstractInitializableComponent.java
@@ -73,7 +73,10 @@ public abstract class AbstractInitializableComponent implements DestructableComp
     
     /**
      * Checks if the component is destroyed and, if so, throws a {@link DestroyedComponentException}.
-     * @deprecated.  This will be removed in V6.0
+     * 
+     * <p>This will be removed in V6.0.</p>
+     * 
+     * @deprecated
      */
     @Deprecated(forRemoval = true, since = "5.3")
     protected void ifDestroyedThrowDestroyedComponentException() {
@@ -127,7 +130,10 @@ public abstract class AbstractInitializableComponent implements DestructableComp
     /**
      * Performs component specific destruction logic. This method is executed within the lock on the object being
      * destroyed. The default implementation of this method is a no-op.
-     * @deprecated.  This will be removed in V6.0.  Replacement is The {@link OnTeardown} annotation.
+     * 
+     * <p>This will be removed in V6.0. Replacement is The {@link OnTeardown} annotation.</p>
+     * 
+     * @deprecated
      */
     @Deprecated(forRemoval = true, since = "5.3")
     protected void doDestroy() {
@@ -146,7 +152,9 @@ public abstract class AbstractInitializableComponent implements DestructableComp
 
     }
 
-    /** Lazy init a logger.
+    /**
+     * Lazy init a logger.
+     * 
      * @return the logger.
      */
     private static Logger getLog() {
diff --git a/shib-support/src/test/java/net/shibboleth/shared/primitive/AnnotationsSupportTest.java b/shib-support/src/test/java/net/shibboleth/shared/primitive/AnnotationsSupportTest.java
index b7f575f2..a19f6d20 100644
--- a/shib-support/src/test/java/net/shibboleth/shared/primitive/AnnotationsSupportTest.java
+++ b/shib-support/src/test/java/net/shibboleth/shared/primitive/AnnotationsSupportTest.java
@@ -23,6 +23,7 @@ import org.testng.annotations.Test;
 import net.shibboleth.shared.annotation.OnTeardown;
 
 /** Tests for {@link AnnotationsSupport}.  */
+ at SuppressWarnings("javadoc")
 public class AnnotationsSupportTest {
 
     private boolean withCalled;
@@ -37,7 +38,7 @@ public class AnnotationsSupportTest {
 
     @Test public void withTest() {
         final var what = new With();
-        assertTrue(AnnotationsSupport.hasPreDestroyAnnotation(what));
+        assertTrue(AnnotationsSupport.hasOnTeardownAnnotation(what));
         AnnotationsSupport.callOnTeardownAnnotations(what);
         assertTrue(withCalled);
         assertFalse(withParamCalled);
@@ -46,7 +47,7 @@ public class AnnotationsSupportTest {
 
     @Test public void withParamTest() {
         final var what = new WithParam();
-        assertFalse(AnnotationsSupport.hasPreDestroyAnnotation(what));
+        assertFalse(AnnotationsSupport.hasOnTeardownAnnotation(what));
         AnnotationsSupport.callOnTeardownAnnotations(what);
         assertFalse(withCalled);
         assertFalse(withDerivedCalled);
@@ -55,7 +56,7 @@ public class AnnotationsSupportTest {
     
     @Test public void withDerivedTest() {
         final var what = new WithDerived();
-        assertTrue(AnnotationsSupport.hasPreDestroyAnnotation(what));
+        assertTrue(AnnotationsSupport.hasOnTeardownAnnotation(what));
         AnnotationsSupport.callOnTeardownAnnotations(what);
         assertTrue(withCalled);
         assertTrue(withDerivedCalled);
@@ -65,7 +66,7 @@ public class AnnotationsSupportTest {
 
     @Test public void withOutTest() {
         final var what = new Without();
-        assertFalse(AnnotationsSupport.hasPreDestroyAnnotation(what));
+        assertFalse(AnnotationsSupport.hasOnTeardownAnnotation(what));
         AnnotationsSupport.callOnTeardownAnnotations(what);
         assertFalse(withCalled);
         assertFalse(withDerivedCalled);

diff --git a/shib-support/src/main/java/net/shibboleth/shared/primitive/AnnotationsSupport.java b/shib-support/src/main/java/net/shibboleth/shared/primitive/AnnotationsSupport.java
index fdfda24b..6d078e84 100644
--- a/shib-support/src/main/java/net/shibboleth/shared/primitive/AnnotationsSupport.java
+++ b/shib-support/src/main/java/net/shibboleth/shared/primitive/AnnotationsSupport.java
@@ -29,7 +29,9 @@ import net.shibboleth.shared.component.IdentifiedComponent;
  */
 public final class AnnotationsSupport {
 
-    /** Call the {@link @OnTeardown} methods.
+    /**
+     * Call the {@link OnTeardown} methods.
+     * 
      * @param obj The object to introspect
      * @param id The id of the object
      * @param log the logger to use
@@ -65,18 +67,23 @@ public final class AnnotationsSupport {
             }
         }
     }
-    /** Call the {@link @PreDestroy} methods.
+    
+    /**
+     * Call the {@link OnTeardown} methods.
      * @param obj The object to introspect
      */
     static public void callOnTeardownAnnotations(@Nullable final Object obj) {
         callOnTeardownAnnotations(obj, null, null);
     }
-    /** Mostly for testing - does this object carry a {@link @PreDestroy} annotated
+    
+    /**
+     * Mostly for testing - does this object carry a {@link OnTeardown} annotated
      * method?
+     * 
      * @param obj The object to introspect
      * @return whether it is tear-downable.
      */
-    static public boolean hasPreDestroyAnnotation(@Nullable final Object obj) {
+    static public boolean hasOnTeardownAnnotation(@Nullable final Object obj) {
         if (obj == null) {
             return false;
         }
-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the commits mailing list